@@ -12,6 +12,7 @@ from typing import TYPE_CHECKING
 import discord
 
 from pylav._logging import getLogger
+from pylav.constants import BUNDLED_PLAYLIST_IDS
 from pylav.envvars import (
     TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS,
     TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS,
@@ -43,6 +44,11 @@ class PlaylistConfigManager:
     def client(self) -> Client:
         return self._client
 
+    @staticmethod
+    async def get_bundled_playlists() -> list[PlaylistModel]:
+        playlists = await tables.PlaylistRow.select().where(tables.PlaylistRow.id.is_in(BUNDLED_PLAYLIST_IDS))
+        return [PlaylistModel(**playlist) for playlist in playlists]
+
     @staticmethod
     async def get_playlist_by_name(playlist_name: str, limit: int = None) -> list[PlaylistModel]:
         if limit is None:
